# Librería Envio Simple


<br>

Librería que te permite enviar una cadena a un servidor en base a las librerias disponibles de Windows 10


<br>

## 💡 Prerequisitos

   [Python 3](https://www.python.org/downloads/release/python-370/)

<br>

## 📚 Ejemplo de uso

```
from SendSingleW10 import SendSingle

SendSingle (Server, Port , Data)
```
<br>

## 🐸 Aloha!
<br>

